@@ -7,10 +7,9 @@ if not os.getenv("READ_THE_DOCS"):
 
 
 class API:
-    def __init__(self, metadata, query=None, ingestion=None):
+    def __init__(self, query=None, ingestion=None):
         self.query = query
         self.ingestion = ingestion
-        self.metadata = metadata
 
     @staticmethod
     def identify(thing_id=None, thing_name=None):
