@@ -5,7 +5,7 @@ from typing import *
 
 from cognite.seismic._api.api import API
 from cognite.seismic._api.utility import MaybeString, get_identifier, get_search_spec
-from cognite.seismic.data_classes.api_types import File
+from cognite.seismic.data_classes.api_types import SourceSegyFile
 from cognite.seismic.data_classes.errors import NotFoundError
 from google.protobuf.struct_pb2 import Struct
 from grpc import StatusCode
@@ -38,7 +38,7 @@ class FileSeismicAPI(API):
             id (int | None): The id of the seismic to retrieve traces from.
             external_id (str | None): The external id of the seismic to retrieve traces from.
             seismic_store_id (int | None): The id of the seismic store to retrieve traces from. Only permitted for data managers.
-            
+
         The returned stream of SegYSeismicResponse objects have a content attribute each containing a fragment of the SEG-Y file.
         Write these to disk in the order received, or stream to a receiver expecting a SEGY bytestream.
 
@@ -146,14 +146,14 @@ class FileSeismicAPI(API):
         if wkt and geo_json:
             raise Exception("Only `wkt` or `geo_json` should be specified")
 
-    def list(self) -> List[File]:
+    def list(self) -> List[SourceSegyFile]:
         """List all files.
 
         Returns:
-            List[:py:class:`~cognite.seismic.data_classes.api_types.File`]: A list of Files.
+            List[:py:class:`~cognite.seismic.data_classes.api_types.SourceSegyFile`]: A list of Files.
         """
         request = SearchFilesRequest()
-        return [File.from_proto(f) for f in self.query.SearchFiles(request)]
+        return [SourceSegyFile.from_proto(f) for f in self.query.SearchFiles(request)]
 
     def search(
         self,
@@ -163,7 +163,7 @@ class FileSeismicAPI(API):
         external_id_substring: MaybeString = None,
         name: MaybeString = None,
         name_substring: MaybeString = None,
-    ) -> Iterable[File]:
+    ) -> Iterable[SourceSegyFile]:
         """Search for files.
 
         Args:
@@ -172,22 +172,22 @@ class FileSeismicAPI(API):
             name_substring (str | None): Substring of a name to search for
 
         Returns:
-            Iterable[:py:class:`~cognite.seismic.data_classes.api_types.File`]: A list of found Files.
+            Iterable[:py:class:`~cognite.seismic.data_classes.api_types.SourceSegyFile`]: A list of found Files.
         """
         spec = get_search_spec(id, external_id, external_id_substring, name, name_substring)
 
         req = SearchFilesRequest(spec=spec)
 
-        return (File.from_proto(f) for f in self.query.SearchFiles(req))
+        return (SourceSegyFile.from_proto(f) for f in self.query.SearchFiles(req))
 
-    def get(self, *, id: Optional[str], external_id: Optional[str] = None) -> File:
+    def get(self, *, id: Optional[str], external_id: Optional[str] = None) -> SourceSegyFile:
         """Fetch a file by id.
 
         Args:
-            file_id (str): The id of the file to fetch
+            id (str | None): The id of the file to fetch
 
         Returns:
-            :py:class:`~cognite.seismic.data_classes.api_types.File`: The retrieved file
+            :py:class:`~cognite.seismic.data_classes.api_types.SourceSegyFile`: The retrieved file
         """
 
         result = self.search(id=id)
