@@ -892,7 +892,8 @@ class SeismicStore:
         survey_id (str): The survey this seismic store belongs to.
         ingestion_source (:py:class:`IngestionSource`): The source of the seismicstore.
         metadata (Mapping[str, str]): Any custom-defined metadata
-        ingested_file (Optional[:py:class:`File`]): If present, the file this SeismicStore was ingested from
+        ingested_file (Optional[:py:class:`File`]): Same as `ingested_source_file` but with less information. Will be removed in a future update.
+        ingested_source_file (Optional[:py:class:`SourceSegyFile`]): If present, the file this SeismicStore was ingested from
         inline_volume_def (Optional[:py:class:`VolumeDef`]): The inline-major volume definition for this seismic store.
         xline_volume_def (Optional[:py:class:`VolumeDef`]): The xline-major volume definition for this seismic store.
         coverage (Optional[:py:class:`Geometry`]): If present, the coverage geometry for this seismic store
@@ -907,6 +908,7 @@ class SeismicStore:
     ingestion_source: IngestionSource
     metadata: Mapping[str, str]
     ingested_file: Optional[File]
+    ingested_source_file: Optional[SourceSegyFile]
     inline_volume_def: Optional[VolumeDef]
     xline_volume_def: Optional[VolumeDef]
     coverage: Geometry
@@ -923,6 +925,7 @@ class SeismicStore:
         ingestion_source,
         metadata,
         ingested_file,
+        ingested_source_file,
         inline_volume_def,
         xline_volume_def,
         coverage,
@@ -936,6 +939,7 @@ class SeismicStore:
         self.ingestion_source = ingestion_source
         self.metadata = metadata
         self.ingested_file = ingested_file
+        self.ingested_source_file = ingested_source_file
         self.inline_volume_def = inline_volume_def
         self.xline_volume_def = xline_volume_def
         self.coverage = coverage
@@ -976,6 +980,7 @@ class SeismicStore:
             ingestion_source=proto.ingestion_source,
             metadata=metadata,
             ingested_file=proto.ingested_file,
+            ingested_source_file=SourceSegyFile.from_proto(proto.ingested_source_file),
             inline_volume_def=inline_volume_def,
             xline_volume_def=xline_volume_def,
             coverage=coverage,
